ClassicalCondition

Enum ClassicalCondition 

pub enum ClassicalCondition {
    BitIsOne(usize),
    BitIsZero(usize),
    RegisterEquals {
        offset: usize,
        size: usize,
        value: u64,
    },
    RegisterNotEquals {
        offset: usize,
        size: usize,
        value: u64,
    },
}
Condition for classically-controlled gate execution.

Variants



BitIsOne(usize)

True when the classical bit at bit is 1.



BitIsZero(usize)

True when the classical bit at bit is 0.



RegisterEquals

True when the classical register (bits offset..offset+size) equals value.

Fields

offset: usize
size: usize
value: u64


RegisterNotEquals

True when the classical register (bits offset..offset+size) does not equal value.

Fields

offset: usize
size: usize
value: u64

Implementations

Source

impl ClassicalCondition

pub fn evaluate(&self, classical_bits: &[bool]) -> bool

Evaluate this condition against a classical bit array.