pub struct BatchPhaseData {
pub phases: SmallVec<[(usize, Complex64); 8]>,
}Expand description
Data for a batched controlled-phase gate.
Multiple cphase gates sharing a control qubit are fused into one pass.
Each entry is (target_qubit, phase). The control qubit is stored in the
instruction’s targets[0].
Fields
phases: SmallVec<[(usize, Complex64); 8]>Trait Implementations
Sourceimpl Clone for BatchPhaseData
impl Clone for BatchPhaseData
Sourcefn clone(&self) -> BatchPhaseData
fn clone(&self) -> BatchPhaseData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchPhaseData
impl Debug for BatchPhaseData
Sourceimpl PartialEq for BatchPhaseData
impl PartialEq for BatchPhaseData
Sourcefn eq(&self, other: &BatchPhaseData) -> bool
fn eq(&self, other: &BatchPhaseData) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchPhaseData