pub fn bitstring(key: &[u64], num_bits: usize) -> StringExpand description
Format a packed Vec<u64> key (from ShotsResult::counts) as a binary string.
Bit 0 of the first word corresponds to classical bit 0 (leftmost character).
pub fn bitstring(key: &[u64], num_bits: usize) -> StringFormat a packed Vec<u64> key (from ShotsResult::counts) as a binary string.
Bit 0 of the first word corresponds to classical bit 0 (leftmost character).