pub struct ObservableVariance {
pub variance: f64,
pub mean: f64,
pub metadata: RunMetadata,
}Expand description
Operator variance of a weighted Pauli observable, returned by
Simulate::observable_variance.
Fields
variance: f64<H^2> - <H>^2 on the output state.
mean: f64<H> on the same state, evaluated on the way to the variance.
metadata: RunMetadataTrait Implementations
Sourceimpl Clone for ObservableVariance
impl Clone for ObservableVariance
Sourcefn clone(&self) -> ObservableVariance
fn clone(&self) -> ObservableVariance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ObservableVariance
impl RefUnwindSafe for ObservableVariance
impl Send for ObservableVariance
impl Sync for ObservableVariance
impl Unpin for ObservableVariance
impl UnsafeUnpin for ObservableVariance
impl UnwindSafe for ObservableVariance